Denne artikel forklarer, hvor konfigurationen af Delivery Checkout adskiller sig fra standardkonfigurationen, når den bruges sammen med nShift Ship.
Afsnit i denne artikel:
- Opret en Delivery Checkout til brug med nShift Ship
- Book og udskriv med nShift Ship
- DeliveryCheckout API
Opret en Delivery Checkout til brug med nShift Ship
Hvis du er ny bruger af Delivery Checkout, anbefaler vi, at du starter med at læse disse artikler:
Før du begynder konfigurationen, skal du sørge for, at du har mindst én afsender i dit adressekartotek. Se Adressekartotek – nShift Delivery Help Center
Du skal også indtaste dit nShift Ship Actor ID og din Key i afsnittet Ship details for din Sender i nShift Delivery:
- Gå til Maintenance > Senders.
- Søg efter din afsender, eller tilføj en ny afsender.
- Indtast dit Actor ID og din Key i afsnittet Ship details.
Følg derefter trinnene i denne artikel: Opret en delivery checkout
Se vores andre artikler om
Flow for Delivery Checkout med nShift Ship:
Book og udskriv med nShift Ship
Du kan booke og udskrive forsendelser med Ship via API eller filimport.
Via API
Hvis du vil booke og udskrive forsendelser via Shipment Server API, skal du bruge prepare ID som OrderId-reference for at udføre handlingen SubmitShipment.
Når du udfører SubmitShipment, skal du tilføje manglende obligatoriske forsendelsesoplysninger, f.eks. pakkeoplysninger.
Læs mere om brug af StoreOrder til at gemme ordrer til import
Filimport
Du kan importere prepare ID og importere denne værdi i References > ShipAdvisor Reference sammen med obligatoriske forsendelsesoplysninger, f.eks. pakkeoplysninger.
Gå til Ship Help her.
DeliveryCheckoutAPI
DeliveryCheckout API er en integrationstjeneste til kommunikation mellem Delivery Checkout og din webshop. DeliveryCheckout API bruger en REST API-ramme til kommunikation med JSON som databærer og tilbyder en række funktioner.
Du finder al den generelle dokumentation for DeliveryCheckoutAPI her.
Når den bruges sammen med nShift Ship, er der nogle få særlige scenarier, som vi gennemgår nedenfor.
Opret en delvis forsendelse
POST /delivery-checkouts/{deliveryCheckoutId}/shipmentsOpretter en delvis forsendelse baseret på den leveringsmulighed, som forbrugeren har valgt i webshoppen.
Dette endpoint er obligatorisk.
Brug altid det komplette Delivery Checkout ID, da Delivery Checkout-versionen er inkluderet i ID'et.
URI-parametre
| deliveryCheckoutId | string | Det Delivery Checkout ID, der returneres fra GET-anmodningen | Påkrævet |
| returnShipmentData | boolean | Forsendelsesdata returneres i svaret. | Valgfri |
Eksempel på body
{
"selectedOptionId": "3e01c458-b4fb-4a15-9468-f9179a516a0c",
"language": "en",
"orderNo": "order number 123",
"prepareId": "test34",
"receiver": {
"name": "Testname",
"address1": "Testaddress 1",
"zipCode": "1080",
"city": "Ixelles",
"country": "BE",
"mobile": "0733000000",
"email": "email2@example.com"
},
"agent": {
"quickId": "19172",
"name": "DISTRIBUTEUR TRIBES BXL CN",
"address1": "Avenue Louise 279",
"address2": null,
"zipCode": "1050",
"city": "Bruxelles",
"state": null,
"country": "BE",
"mapLongitude": 4.36706,
"mapLatitude": 50.82386,
"phone": null,
"email": null
}
}
Eksempel på svar
{
"sourceSystem": "DH",
"serviceId": "DH:7132",
"optionTitle": "PostNord Varubrev 1:a klass (7132)",
"serviceCaption": "PostNord Varubrev 1:a klass (7132)",
"addons": []
}
Se referencevejledningen for egenskaber for en beskrivelse af egenskaberne.
Se https://api.unifaun.com/rs-docs/ for skema og test, og gå til /delivery-checkouts/{deliveryCheckoutId}/shipments POST.
Hent en delvis forsendelse
GET /delivery-checkout-shipments/{prepareId}Henter en delvis forsendelse, der tidligere er blevet oprettet.
URI-parametre
| prepareId | string | Identifikation af den delvise forsendelse. | Påkrævet |
Eksempel på svar
{
"serviceId": "DCTEST",
"serviceTitle": "Delivery Checkout Test Service",
"sourceSystem": "UO",
"orderNo": "order number 123",
"prepareId": "123",
"sender": {
"quickId": "1",
"name": "nShift AB",
"address1": "Skeppsbron 5-6",
"postalCode": "41121",
"city": "GÖTEBORG",
"country": "SE",
"phone": "+46 31 725 35 00",
"email": "email1@example.com"
},
"receiver": {
"name": "nShift AB",
"address1": "Tegnérgatan 34",
"postalCode": "11359",
"city": "STOCKHOLM",
"country": "SE",
"phone": "+46 8 34 35 15",
"email": "email2@example.com"
}
}Se referencevejledningen for egenskaber for en beskrivelse af egenskaberne.
Se https://api.unifaun.com/rs-docs/ for skema og test, og gå til /delivery-checkout-shipments/{prepareId} GET.
Slet en delvis forsendelse
DELETE /delivery-checkout-shipments/{prepareId}Sletter en delvis forsendelse.
Når den delvise forsendelse er slettet, kan prepare ID'et genbruges til nye delvise forsendelser.
URI-parametre
| prepareId | string | Identifikation af den delvise forsendelse | Påkrævet |
Der returneres ingen response body, når en delvis forsendelse er blevet slettet.
Se referencevejledningen for egenskaber for en beskrivelse af egenskaberne.
Se https://api.unifaun.com/rs-docs/ for skema og test, og gå til /delivery-checkout-shipments/{prepareId} DELETE.
Hent tjenestens kildesystem
GET /delivery-checkout-shipments/{prepareId}/source-systemHenter det kildesystem, som den delvise forsendelsestjeneste stammer fra.
Nyttigt, hvis kun prepare ID'et er kendt, og Delivery Checkout-konfigurationen indeholder muligheder med tjenester fra flere kildesystemer.
URI-parametre
| prepareId | string | Identifikation af den delvise forsendelse. | Påkrævet |
Se referencevejledningen for egenskaber for en beskrivelse af egenskaberne.
Se https://api.unifaun.com/rs-docs/ for skema og test, og gå til /delivery-checkout-shipments/{prepareId}/source-system GET.